@@ -62,6 +62,12 @@ int  main(int argc, char **argv)
       {"",""}  /* DON'T REMOVE THIS LINE */
     };
 
+  /* if this is executed in shell with '-v' option, show make dir */  
+  if(argc>1 && strcmp(argv[1],"-v")==0){
+    printf("makedir: %s\n", MAKEDIR);
+    exit(0);
+  }
+
   /* prepare config file */
   if(OpenConfFile()==-1)return 0;
  
@@ -93,7 +99,7 @@ int  main(int argc, char **argv)
   if(isNull(getenv("QUERY_STRING"))){
     lang[0]='\0';
   }else{
-    strncpy(lang, getenv("QUERY_STRING"), ADDRMAXLN);
+    strlcpy(lang, getenv("QUERY_STRING"), ADDRMAXLN);
   }
      
   /* if not get, use default lang at the top of lang list */
@@ -110,13 +116,11 @@ int  main(int argc, char **argv)
   if(isNull(getenv("REMOTE_ADDR"))){
     clientAddr[0]='\0';
   }else{
-    strncpy(clientAddr,getenv("REMOTE_ADDR"),ADDRMAXLN);
+    strlcpy(clientAddr,getenv("REMOTE_ADDR"),ADDRMAXLN);
   }
 
-  /* encode the address(if IPv6 addr, fail) */
-  if(AddrEncode(encodeAddr, clientAddr)==1){
-    encodeAddr[0]='\0';
-  }
+  /* encode the address(if IPv6 addr, return 0-0-0) */
+  AddrEncode(encodeAddr, clientAddr);
 
   /* construct redirected(requested) URL */
   /* protocol */
